@@ -64,10 +64,6 @@ def cache_tiddlers(package_name):
 	tiddler files are stored in <package>/resources/<bag>
 	a complete index is stored in <package>/resources
 	"""
-	# extend module search path for access to local mangler.py
-	sys.path.insert(0, os.getcwd())
-	import mangler
-
 	instance_module = __import__("%s.instance" % package_name,
 		fromlist=["instance"]) # XXX: unnecessarily convoluted and constraining!?
 	store_contents = instance_module.store_contents
